@@ -11,14 +11,14 @@ class QuerySearch(ABC):
         source: str = "data",
     ) -> Any:
 
-        self.validate_data(data, source)
+        self._validate_data(data, source)
 
         if not data:
             return data
 
-        data = self.process_data(data, source)
+        data = self._process_data(data, source)
 
-        return self.parse(data)
+        return self._parse(data)
 
     def get_all(
         self,
@@ -33,16 +33,16 @@ class QuerySearch(ABC):
         source: Optional[str] = None,
     ) -> Iterable[Any]:
 
-        self.validate_data(data, source)
+        self._validate_data(data, source)
 
         if not data:
             return data
 
-        data = self.process_data(data, source)
+        data = self._process_data(data, source)
 
-        yield from self.iter_parse(data)
+        yield from self._iter_parse(data)
 
-    def validate_data(
+    def _validate_data(
         self,
         data: Any,
         source: Optional[str] = None,
@@ -54,21 +54,21 @@ class QuerySearch(ABC):
             )
 
     @abstractmethod
-    def parse(
+    def _parse(
         self,
         data: Any,
     ):
         pass
 
     @abstractmethod
-    def iter_parse(
+    def _iter_parse(
         self,
         data: Any,
     ) -> Iterable[Any]:
         pass
 
     @abstractmethod
-    def process_data(
+    def _process_data(
         self,
         data: Any,
         source: Optional[str] = None,
