@@ -5,9 +5,9 @@ from easydata.queries import pq
 
 
 class PricingBlock(Block):
-    item_price = parsers.PriceFloat(pq("#price").text)
+    item_price = parsers.PriceFloat(pq("#price::text"))
 
-    item_sale_price = parsers.PriceFloat(pq("#sale-price").text)
+    item_sale_price = parsers.PriceFloat(pq("#sale-price::text"))
 
     items_processors = [("discount", ItemDiscountProcessor())]
 
